---
title: <span class="badge object-type-scalar"></span> MetricTon
---
# <span class="badge object-type-scalar"></span> MetricTon

Mass: metric ton (t)

## Definition

```python
# Mass: metric ton (t)
MetricTon: typing.Literal["masst"] = "masst"
```
